// src/converters/ArrayParam.ts
function ArrayParam(elementConfig) {
  return {
    serialize: (values) => {
      if (!values) {
        return null;
      }
      return values.map(elementConfig.serialize);
    },
    deserialize: (values) => {
      if (!values) {
        return null;
      }
      if (!Array.isArray(values)) {
        return [elementConfig.deserialize(values)];
      }
      return values.map(elementConfig.deserialize);
    }
  };
}

// src/converters/BooleanParam.ts
var BooleanParam = {
  serialize: (value) => typeof value === "boolean" ? value.toString() : null,
  deserialize: (value) => {
    if (value === "true")
      return true;
    if (value === "false")
      return false;
    return null;
  }
};

// src/converters/DateParam.ts
var DateParam = {
  serialize: (value) => (value == null ? void 0 : value.toISOString()) ?? null,
  deserialize: (value) => {
    const stringValue = value;
    try {
      const date = new Date(stringValue);
      return isNaN(date.getTime()) ? null : date;
    } catch {
      return null;
    }
  }
};

// src/converters/NumberParam.ts
var NumberParam = {
  serialize: (value) => Number.isFinite(value) ? `${value}` : null,
  deserialize: (value) => {
    try {
      const parsedValue = Number.parseFloat(value);
      return Number.isFinite(parsedValue) ? parsedValue : null;
    } catch {
      return null;
    }
  }
};

// src/converters/ObjectParam.ts
function ObjectParam() {
  return {
    serialize: (value) => value === null ? null : encodeURIComponent(JSON.stringify(value)),
    deserialize: (value) => {
      if (value === null || Array.isArray(value)) {
        return null;
      }
      try {
        return JSON.parse(decodeURIComponent(value));
      } catch {
        return null;
      }
    }
  };
}

// src/converters/StringParam.ts
var StringParam = {
  serialize: (value) => value,
  deserialize: (value) => value ?? null
};

export {
  ArrayParam,
  BooleanParam,
  DateParam,
  NumberParam,
  ObjectParam,
  StringParam
};
//# sourceMappingURL=chunk-XRAUOHHC.mjs.map